@@ -1,5 +1,5 @@
 package HTTP::Engine::Role::RequestBuilder::ParseEnv;
-use Mouse::Role;
+use Any::Moose '::Role';
 
 with 'HTTP::Engine::Role::RequestBuilder::Standard' => {
     alias => { _build_hostname => "_resolve_hostname" }, # we might be able to get it from the env
